using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using CommonData;

namespace SalesDomain
{
  public class Order
  {
    public static Order CreateOrder(CustomerForOrderTransferDTO customer)
    {
      return new Order(customer);
    }

    private Order(CustomerForOrderTransferDTO customer)
    {
     
      LineItems = new List<LineItem>();
      CustomerId = customer.CustomerId;
      OrderDate = DateTime.Now;
      ModifiedDate = DateTime.Now;
      SetShippingAddress(customer.ShippingAddress);
      switch (customer.Status)
      {
        case CustomerStatus.Silver:
          CustomerDiscount = 0;
          break;
        case CustomerStatus.Gold:
          CustomerDiscount = .05;
          break;
        case CustomerStatus.Platinum:
          CustomerDiscount = .1;
          break;
      }
    }
    private Order()
    {
      LineItems = new List<LineItem>();
    }

    public int OrderId { get; private set; }
    public DateTime OrderDate { get; private set; }
    public Nullable<DateTime> DueDate { get; private set; }
    public bool OnlineOrder { get; private set; }
    public string PurchaseOrderNumber { get; private set; }
    public string Comment { get; private set; }
    public int PromotionId { get; private set; }
    //persisting the address used for this order in case
    //customer.shippingAddress changes in the future
    public Address ShippingAddress { get; private set; }

    public void SetShippingAddress(Address address)
    {
      ShippingAddress = new Address(
        address.Street1, address.Street2, address.City,
        address.Region, address.Country, address.PostalCode);
    }


    public double Discount
    {
      get { return CustomerDiscount + PromoDiscount; }
    }

    public double CustomerDiscount { get; private set; }
    public double PromoDiscount { get; private set; }


    public void SetOrderDetails(bool onLineOrder, string PONumber, string comment, Promotion promotion)
    {
      OnlineOrder = onLineOrder;
      PurchaseOrderNumber = PONumber;
      Comment = comment;
      if (promotion != null)
      {
        PromotionId = promotion.PromotionId;
        PromoDiscount = promotion.Discount;
      }
    }

    public string SalesOrderNumber { get; private set; }

    public int CustomerId { get; private set; }
    public double SubTotal { get; private set; }
    public DateTime ModifiedDate { get; private set; }
    public ICollection<LineItem> LineItems { get; private set; }
public void CreateLineItem(Product product, int quantity)
{
  //NOTE: add some validations such as:
  //quantity can't be 0 and if it's >1000 give a discount
  // customer is a gold. give another discount
  var item = new LineItem
    (OrderId, product.ProductId, quantity, product.ListPrice,
    CustomerDiscount + PromoDiscount);
  LineItems.Add(item);
}


  }
}