﻿using System;
using System.Data.Entity;
using DataLayer.Sales;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using SalesDomain;
using System.Linq;

namespace SalesDomainTests
{
  [TestClass]
  public class UnitTest1
  {
 
    [TestMethod, TestCategory("UnitTest")]
    public void SilverCustomerPlusPromoDiscountEqualToPromoDiscount()
    {

      var cust = new CustomerForOrderTransferDTO
      {
        CustomerId = 1,
        Status = CustomerStatus.Silver,
        ShippingAddress = new Address("1 Main", null, "Las Vegas", "NV", "US", "11111")
      };
      var order = Order.CreateOrder(cust);
      order.SetOrderDetails(false, "1234", "hurry!", new Promotion {Discount = .05, StartDate = DateTime.Now});
      Assert.AreEqual(.05, order.Discount);
    }
    [TestMethod, TestCategory("UnitTest")]
    public void GoldCustomerPlusPromoDiscountEqualToGoldPlusPromoDiscount()
    {
      var cust = new CustomerForOrderTransferDTO
                   {
                     CustomerId = 1,
                     Status = CustomerStatus.Gold,
                     ShippingAddress = new Address("1 Main", null, "Las Vegas", "NV", "US", "11111")
                   };
      
      var order = Order.CreateOrder(cust);
      order.SetOrderDetails(false, "1234", "hurry!", new Promotion { Discount = .05, StartDate = DateTime.Now });
      Assert.AreEqual(.1, order.Discount);
    }



 [TestMethod, TestCategory("IntegrationTest")]
 public void SaveNewLineItemForOrderInDatabase()
 {
  
      Database.SetInitializer(new SalesContextSeedInitilializer());
 
   Order order;
   Product product;
   using (var context = new DataLayer.Sales.SalesContext())
   {
     order = context.Orders.FirstOrDefault();
     product = context.Products.FirstOrDefault();
   }
   order.CreateLineItem(product, 2);
   var repo = new SimpleOrderRepository();
   repo.UpdateLineItemsForExistingOrder(order);
   repo.Save();

   Assert.Inconclusive("Check Database and Profiler for results");
 }

 [TestMethod, TestCategory("IntegrationTest")]
 public void SaveNewLineItemForNewOrderInDatabase()
 {
   Database.SetInitializer(new SalesContextSeedInitilializer());
 
   var customer = new CustomerForOrderTransferDTO {CustomerId =1, ShippingAddress = new Address("1 main",null,"newcity","NY","US","12121")};
   var order = Order.CreateOrder(customer);
   Product product;
   using (var context = new DataLayer.Sales.SalesContext())
   {
     product = context.Products.FirstOrDefault();
   }
   order.CreateLineItem(product, 2);
   var repo = new SimpleOrderRepository();
   repo.AddNewOrderGraph(order);
   repo.Save();

   Assert.Inconclusive("Check Database and Profiler for results. The interesting info is what the inserts look like");
 }
  }
}
